// import { error } from '@sveltejs/kit';
// import Wikiapi from 'wikiapi';
import unslugify from 'unslugify';
import { WBK } from 'wikibase-sdk';
import dayjs from 'dayjs';

const wdk = WBK({
	instance: 'https://www.wikidata.org',
	sparqlEndpoint: 'https://query.wikidata.org/sparql'
});

// month is zero-indexed
export type Birth = { year: number; month: number; day: number };
export type Entry = { name: string; birth: Birth };

let cache = new Map<string, Entry>();

/** @type {import('./$types').PageLoad} */
export async function load({ params }) {
	const query = unslugify(params.slug);

	if (cache.has(query)) {
		return cache.get(query)!;
	} else {
		// const data = await wiki.data(query, 'P569');
		// if (data.length === 0) throw error(404, 'Not found');
		// const [year, month, day] = data[0];

		const url = wdk.getEntitiesFromSitelinks({ titles: [query] });
		const json = await fetch(url).then((res) => res.json());
		let name = query;
		if (json.normalized?.n) {
			name = json.normalized.n.to;
		}
		const entity = json.entities[Object.keys(json.entities)[0]];
		const birthday = dayjs(entity.claims?.P569[0]?.mainsnak?.datavalue?.value?.time);
		const birth: Birth = {
			year: birthday.year(),
			month: birthday.month(),
			day: birthday.date()
		};
		const entry: Entry = { name, birth };
		cache.set(query, entry);
		return entry;
	}
}
